==> haskell-tasty-sugar-2.2.1.0-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-sugar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-tasty-sugar-z-tasty-sugar-internal
version:              2.2.1.0
package-name:         tasty-sugar
lib-name:             tasty-sugar-internal
id:
    tasty-sugar-2.2.1.0-E6FJKKic25EJhHq3IaZyca-tasty-sugar-internal

key:
    tasty-sugar-2.2.1.0-E6FJKKic25EJhHq3IaZyca-tasty-sugar-internal

license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  523840e2dbc058a5ff74faca5470a7da
exposed-modules:
    Test.Tasty.Sugar.Analysis Test.Tasty.Sugar.AssocCheck
    Test.Tasty.Sugar.Candidates Test.Tasty.Sugar.ExpectCheck
    Test.Tasty.Sugar.Iterations Test.Tasty.Sugar.ParamCheck
    Test.Tasty.Sugar.Ranged Test.Tasty.Sugar.Report
    Test.Tasty.Sugar.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:
    HStasty-sugar-2.2.1.0-E6FJKKic25EJhHq3IaZyca-tasty-sugar-internal

depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    filemanip-0.3.6.3-2QI3Xdwf7e9Gx6Xld8cP6I filepath-1.4.2.2
    kvitable-1.0.3.0-9ZTYUgtFJ92FC7OqtiBD0Z
    logict-0.7.1.0-5xTmrN3e1x0ARkfDHh111j
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd mtl-2.2.2
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
    prettyprinter-1.7.1-2SyS45w2YIjHD6NDr8Zx1B text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-sugar
version:              2.2.1.0
visibility:           public
id:                   tasty-sugar-2.2.1.0-EAypIGCvb16CGlFzojtRGj
key:                  tasty-sugar-2.2.1.0-EAypIGCvb16CGlFzojtRGj
license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  fcd9ff90c41eb00579c220ce5181d0f4
exposed:              True
exposed-modules:      Test.Tasty.Sugar
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:         HStasty-sugar-2.2.1.0-EAypIGCvb16CGlFzojtRGj
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    filemanip-0.3.6.3-2QI3Xdwf7e9Gx6Xld8cP6I filepath-1.4.2.2
    logict-0.7.1.0-5xTmrN3e1x0ARkfDHh111j
    optparse-applicative-0.17.1.0-CKO7Hv5HIMoIThZFruc57S
    prettyprinter-1.7.1-2SyS45w2YIjHD6NDr8Zx1B
    tasty-1.4.3-F9OqaL2hK2T3ibNso1WybZ
    tasty-sugar-2.2.1.0-E6FJKKic25EJhHq3IaZyca-tasty-sugar-internal
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-sugar-2.2.1.0-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-sugar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-tasty-sugar-z-tasty-sugar-internal
version:              2.2.1.0
package-name:         tasty-sugar
lib-name:             tasty-sugar-internal
id:
    tasty-sugar-2.2.1.0-BY18cSqTFO73kG1i5zEVF2-tasty-sugar-internal

key:
    tasty-sugar-2.2.1.0-BY18cSqTFO73kG1i5zEVF2-tasty-sugar-internal

license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  e9b1424f7acf9c16b92d113dea6b874c
exposed-modules:
    Test.Tasty.Sugar.Analysis Test.Tasty.Sugar.AssocCheck
    Test.Tasty.Sugar.Candidates Test.Tasty.Sugar.ExpectCheck
    Test.Tasty.Sugar.Iterations Test.Tasty.Sugar.ParamCheck
    Test.Tasty.Sugar.Ranged Test.Tasty.Sugar.Report
    Test.Tasty.Sugar.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:
    HStasty-sugar-2.2.1.0-BY18cSqTFO73kG1i5zEVF2-tasty-sugar-internal

depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    filemanip-0.3.6.3-2QI3Xdwf7e9Gx6Xld8cP6I filepath-1.4.2.2
    kvitable-1.0.3.0-5P2D3UjWfUVDo8ee43LL7m
    logict-0.7.1.0-5xTmrN3e1x0ARkfDHh111j
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd mtl-2.2.2
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
    prettyprinter-1.7.1-2SyS45w2YIjHD6NDr8Zx1B text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-sugar
version:              2.2.1.0
visibility:           public
id:                   tasty-sugar-2.2.1.0-97GhjjFLWQkAZivzN26nvZ
key:                  tasty-sugar-2.2.1.0-97GhjjFLWQkAZivzN26nvZ
license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  4e5ac1fdcb22cc9ef37e9c198558cab3
exposed:              True
exposed-modules:      Test.Tasty.Sugar
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:         HStasty-sugar-2.2.1.0-97GhjjFLWQkAZivzN26nvZ
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    filemanip-0.3.6.3-2QI3Xdwf7e9Gx6Xld8cP6I filepath-1.4.2.2
    logict-0.7.1.0-5xTmrN3e1x0ARkfDHh111j
    optparse-applicative-0.17.1.0-CKO7Hv5HIMoIThZFruc57S
    prettyprinter-1.7.1-2SyS45w2YIjHD6NDr8Zx1B
    tasty-1.4.3-F9OqaL2hK2T3ibNso1WybZ
    tasty-sugar-2.2.1.0-BY18cSqTFO73kG1i5zEVF2-tasty-sugar-internal
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
